@@ -1,4 +1,6 @@
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
+#![warn(clippy::print_stderr)]
+#![warn(clippy::print_stdout)]
 
 pub use crate::cobalt::build;
 pub use crate::cobalt::classify_path;
@@ -15,3 +17,7 @@ mod pagination;
 mod syntax_highlight;
 
 pub use crate::syntax_highlight::SyntaxHighlight;
+
+#[doc = include_str!("../README.md")]
+#[cfg(doctest)]
+pub struct ReadmeDoctests;
